@@ -7,7 +7,7 @@
 #------------------------------------------------
  package Net::UploadMirror::FileName;
  use Storable;
- sub TIESCALAR{ my ($class, $obj) = @_; return(bless(\$obj, $class || ref($class))); }
+ sub TIESCALAR{ my ($class, $obj) = @_; return bless(\$obj, $class || ref($class)); }
  sub STORE 
  	{
  	if(-f $_[1])
@@ -21,16 +21,16 @@
  		warn("\nno information of the files last modified times\n");
  		}
  	}
- sub FETCH { return(${$_[0]}->{_filename}); }
+ sub FETCH { return ${$_[0]}->{_filename}; }
 #-------------------------------------------------
  package Net::UploadMirror;
 #-------------------------------------------------
- use Net::MirrorDir 0.18;
+ use Net::MirrorDir 0.19;
  use Storable;
  use vars '$AUTOLOAD';
 #------------------------------------------------
  @Net::UploadMirror::ISA = qw(Net::MirrorDir);
- $Net::UploadMirror::VERSION = '0.11';
+ $Net::UploadMirror::VERSION = '0.12';
 #-------------------------------------------------
  sub _Init
  	{
@@ -38,13 +38,13 @@
 	tie($self->{_filename}, "Net::UploadMirror::FileName", $self);
  	$self->{_filename}	= $arg{filename}	|| "lastmodified_local";
  	$self->{_delete}	= $arg{delete}	|| "disabled";
- 	return(1);
+ 	return 1;
  	}
 #-------------------------------------------------
  sub Upload
  	{
  	my ($self) = @_;
- 	return(0) unless($self->Connect());
+ 	return 0 unless($self->Connect());
  	my ($rh_lf, $rh_ld) = $self->ReadLocalDir();
  	if($self->{_debug})
  		{
@@ -91,7 +91,7 @@
  		$self->RemoveDirs($ra_rdnil);
  		}
  	$self->Quit();
- 	return(1);
+ 	return 1;
  	}
 #-------------------------------------------------
  sub CheckIfModified
@@ -107,13 +107,13 @@
  			}
  		push(@mf, $lf);
  		}
- 	return(\@mf);
+ 	return \@mf;
  	}
 #-------------------------------------------------
 sub StoreFiles
  	{
  	my ($self, $ra_lf) = @_;
- 	return(0) unless(@{$ra_lf} && $self->IsConnection());
+ 	return 0 unless(@{$ra_lf} && $self->IsConnection());
  	my $rf;
  	for my $lf (@{$ra_lf})
  		{
@@ -129,13 +129,13 @@ sub StoreFiles
  			}
  		}
  	store($self->{_last_modified}, $self->{_filename});
- 	return(1);
+ 	return 1;
  	}	
 #-------------------------------------------------
  sub MakeDirs
  	{
  	my ($self, $ra_ld) = @_;
- 	return(0) unless(@{$ra_ld} && $self->IsConnection());
+ 	return 0 unless(@{$ra_ld} && $self->IsConnection());
  	for my $ld (@{$ra_ld})
  		{
  		if(-d $ld)
@@ -148,13 +148,13 @@ sub StoreFiles
 			warn("error in MakeDirs() : $ld is not a local directory\n");
  			}
  		}
- 	return(1);
+ 	return 1;
  	}
 #-------------------------------------------------
  sub DeleteFiles
  	{
  	my ($self, $ra_rf) = @_;
-	return(0) unless(
+	return 0 unless(
  		@{$ra_rf} &&
  		($self->{_delete} eq "enable") &&
  		$self->IsConnection()
@@ -168,19 +168,19 @@ sub StoreFiles
  		delete($self->{_last_modified}{$lf}) if(defined($self->{_last_modified}{$lf}));
  		}
  	store($self->{_last_modified}, $self->{_filename});
- 	return(1);
+ 	return 1;
  	}
 #-------------------------------------------------
  sub RemoveDirs
  	{
  	my ($self, $ra_rd) = @_;
-	return(0) unless(
- 		@{$ra_rd} &&
- 		($self->{_delete} eq "enable") &&
+	return 0 unless(
+ 		@{$ra_rd}			&&
+ 		($self->{_delete} eq "enable")	&&
  		$self->IsConnection()
  		);
  	$self->{_connection}->rmdir($_, 1) for(@{$ra_rd});
- 	return(1);
+ 	return 1;
  	}
 #------------------------------------------------
 1;
@@ -196,7 +196,7 @@ Net::UploadMirror - Perl extension for mirroring a local directory via FTP to th
   use Net::UploadMirror;
   my $um = Net::UploadMirror->new(
  	ftpserver		=> "my_ftp.hostname.com",
- 	usr		=> "my_ftp_usr_name",
+ 	user		=> "my_ftp_user_name",
  	pass		=> "my_ftp_password",
  	);
  $um->Upload();
@@ -204,7 +204,7 @@ Net::UploadMirror - Perl extension for mirroring a local directory via FTP to th
  or more detailed
  my $md = Net::UploadMirror->new(
  	ftpserver		=> "my_ftp.hostname.com",
- 	usr		=> "my_ftp_usr_name",
+ 	user		=> "my_ftp_user_name",
  	pass		=> "my_ftp_password",
  	localdir		=> "home/nameA/homepageA",
  	remotedir	=> "public",
@@ -246,19 +246,7 @@ But there are not in principle any limits.
  This function is called by the constructor.
  You do not need to call this function by yourself.
 
-=item (1|0)Upload(void)
- Call this function for mirroring automatically, recommended!!!
-
-=item (ref_hash_modified_files)CheckIfModified(ref_list_local_files)
- Takes a hashreference of local filenames to compare the last modification time,
- which is stored in a file, named by the attribute "filename", while uploading. 
- Returns a reference of a list.
-
-=item (1|0)StoreFiles(ref_array_paths)
- Takes a arrayreference of local-paths to upload the files via FTP.
-
-=item (1|0)MakeDirs(ref_array_paths)
- Takes a arrayreference of directories to make in the remote location.
+=item (1|0)Upload(                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                nce of directories to make in the remote location.
 
 =item (1|0)DeleteFiles(ref_array_paths)
  Takes a arrayreference of files to delete in the remote location.
@@ -312,6 +300,4 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.9.2 or,
 at your option, any later version of Perl 5 you may have available.
 
-
 =cut
-
